<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html"/>
<xsl:template match="/">

<div>
  <xsl:attribute name="style">
      <xsl:value-of select="doc/stylePreferences/font"/>
      <xsl:value-of select="doc/stylePreferences/background-color"/>
      <xsl:value-of select="doc/stylePreferences/color"/>
  </xsl:attribute>
  <xsl:attribute name="data-ghHeaderWithCloseTag">div</xsl:attribute>
  
  <xsl:value-of select="doc/composition/focus"/>
  <div><br/></div>
  
  <xsl:value-of select="doc/identity/signature"/>

  <xsl:call-template name="autoFilledAttachments"/>

  <xsl:call-template name="forwardedMessages"/>
  
</div>

</xsl:template>

<!-- ====================================== -->
<!--Template that includes the autoFilled attachments -->
<xsl:template name="autoFilledAttachments">
    <xsl:call-template name="attachmentList">
        <xsl:with-param name="list" select="doc/composition/autoFilledAttachments/attachment"/>
    </xsl:call-template>
</xsl:template>
<!-- ====================================== -->


<!-- ====================================== -->
<!-- The images for the given attachment list -->
<xsl:template name="attachmentList">
    <xsl:param name="list" />

    <xsl:for-each select="$list">
        <img>
            <xsl:attribute name="src">
                <xsl:value-of select="attachmentImgUrl"/>
            </xsl:attribute>
            <xsl:attribute name="style">max-width:96% ; width: auto; height: auto; margin-bottom:1em; </xsl:attribute>
        </img><BR/>
    </xsl:for-each>
</xsl:template>
<!-- ====================================== -->



<!-- ====================================== -->
<!--Template that includes the text of all messages being forwarded-->
<xsl:template name="forwardedMessages">

<xsl:for-each select="doc/reference">
    <xsl:if test="position() != 1">
      <BR/>
----
<BR/>
    </xsl:if>
  <xsl:call-template name="forwardedMessage">
        <xsl:with-param name="reference" select="."/>
        <xsl:with-param name="identity" select="../identity"/>
 </xsl:call-template>
</xsl:for-each>

</xsl:template>
<!-- ====================================== -->



<!-- ====================================== -->
<!--Template that includes the forwarded text of one email -->
<xsl:template name="forwardedMessage">
  <xsl:param name="reference" />
  <xsl:param name="identity" />


<BR/>
<xsl:value-of select="$identity/fwdHeader"/>

From: <xsl:value-of select="$reference/from/person/statedNameAndEmailAddress"/><BR/>
Date: <xsl:value-of select="$reference/sentTime/datetime/datetime_imap"/><BR/>
To: <xsl:call-template name="peopleList">
        <xsl:with-param name="list" select="$reference/to/person"/>
    </xsl:call-template><BR/>

<xsl:if test="number($reference/cc/personCount) &gt; 0 ">
  Cc: <xsl:call-template name="peopleList">
        <xsl:with-param name="list" select="$reference/cc/person"/>
        </xsl:call-template><BR/>
</xsl:if>


Subject: <xsl:value-of select="$reference/subject"/>
<div><br/></div>
<xsl:value-of select="$reference/htmlBody"/>
<div><br/></div>

</xsl:template>
<!-- ====================================== -->



<!-- ====================================== -->
<!--Template that joins multiple people as email addresses and names-->
<xsl:template name="peopleList">
  <xsl:param name="list" />
  
  <xsl:for-each select="$list">
    <xsl:value-of select="statedNameAndEmailAddress" />
    <xsl:if test="position() != last()">, </xsl:if>
  </xsl:for-each>
</xsl:template>
<!-- ====================================== -->

</xsl:stylesheet>


